/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2006 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: SoapComponent.java 154 25 sept. 06 alouis $
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.binding.soap;

import java.io.File;
import java.util.logging.Level;

import javax.jbi.JBIException;

import org.apache.axis2.AxisFault;
import org.apache.axis2.context.ConfigurationContext;
import org.apache.axis2.context.ConfigurationContextFactory;
import org.objectweb.petals.binding.soap.listener.incoming.SoapListenerManager;
import org.objectweb.petals.binding.soap.listener.outgoing.JBIListener;
import org.objectweb.petals.component.common.bc.AbstractBindingComponent;
import org.objectweb.petals.component.common.su.SimpleServiceUnitManager;

/**
 * The SOAP binding component.
 * 
 * @author alouis - EBM Websourcing
 * @author chamerling - EBM Websourcing
 * 
 */
public class SoapComponent extends AbstractBindingComponent {

    /**
     * The listener processing request provided by the NMR. Outgoing requests.
     */
    protected JBIListener listener;

    /**
     * The listener processing SOAP request providing from external clients.
     * Incoming SOAP requests.
     */
    protected SoapListenerManager externalListenerManager;

    /**
     * The SOAP component context
     */
    protected SoapComponentContext soapContext;

    @Override
    public void start() throws JBIException {
        super.start();
        try {
            externalListenerManager.start();
        } catch (AxisFault e) {
            getLogger().severe(e.getMessage());
            throw new JBIException(e);
        }
    }

    @Override
    public void stop() throws JBIException {
        super.stop();
        try {
            externalListenerManager.stop();
        } catch (AxisFault e) {
            getLogger().severe(e.getMessage());
            throw new JBIException(e);
        }
    }

    @Override
    protected void init(BindingComponentInitializer initializer)
            throws JBIException {

        // create the SOAP component context
        soapContext = new SoapComponentContext();

        // get the BindingSUManager
        SimpleServiceUnitManager bindingSUM = (SimpleServiceUnitManager) getServiceUnitManager();

        // get axis configuration context
        ConfigurationContext axisConfigurationContext = null;
        try {
            axisConfigurationContext = ConfigurationContextFactory
                    .createConfigurationContextFromFileSystem(getContext()
                            .getInstallRoot(), getContext().getInstallRoot()
                            + File.separator + "axis2.xml");
        } catch (AxisFault e) {
            getLogger().log(Level.WARNING, e.getMessage());
            throw new JBIException("Can not initialize SOAP BC", e);
        }

        // create internal listener, will handle internal WS queries to external
        // services
        listener = new JBIListener(soapContext, getLogger());

        // create external listener, will handle incoming SOAP queries
        externalListenerManager = new SoapListenerManager(getContext(),
                getChannel(), bindingSUM, axisConfigurationContext,
                extensionProperties, getLogger());

        // set service unit listener
        SoapSUListener suListener = new SoapSUListener(soapContext,
                axisConfigurationContext, getContext(), externalListenerManager
                        .getServicesURL(), getLogger());
        setServiceUnitListener(suListener);
        
        // set BC listeners
        initializer.setExternalListenerManager(externalListenerManager);
        initializer.setJbiListener(listener);
    }
}
