/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.binding.soap;

import java.util.HashMap;
import java.util.Map;

import org.objectweb.petals.component.common.ComponentPropertiesManager;

/**
 * The SOAP component properties
 * 
 * @author Christophe HAMERLING - eBMWebSourcing
 * 
 */
public class SoapProperties {

    public static final String HTTP_PORT = "http.port";

    public static final String ENABLE_SERVICES_LIST = "http.services.list";

    public static final int DEFAULT_HTTP_PORT = 8084;

    public static final String SERVICES_CONTEXT = "http.services.context";

    public static final String SERVICES_MAPPING = "http.services.mapping";

    public static final boolean DEFAULT_ENABLE_SERVICES_LIST = true;

    public static final String DEFAULT_PROTOCOL = "http";

    public static final String DEFAULT_SERVICES_CONTEXT = "axis2";

    public static final String DEFAULT_SERVICES_MAPPING = "services";

    private ComponentPropertiesManager propertiesManager;

    /**
     * Creates a new instance of {@link SoapProperties}
     * 
     * @param properties
     */
    public SoapProperties(ComponentPropertiesManager propertiesManager) {
        this.propertiesManager = propertiesManager;
    }

    /**
     * Get the HTTP port
     * 
     * @return
     */
    public int getHttpPort() {
        return Integer.parseInt(propertiesManager.getAttribute(HTTP_PORT,
                Integer.toString(DEFAULT_HTTP_PORT)));
    }

    /**
     * Does the component have to provide the services list
     * 
     * @return
     */
    public boolean isProvidingServicesList() {
        return Boolean.parseBoolean(propertiesManager.getAttribute(
                ENABLE_SERVICES_LIST, Boolean
                        .toString(DEFAULT_ENABLE_SERVICES_LIST)));
    }

    public String getServicesContext() {
        return propertiesManager.getAttribute(SERVICES_CONTEXT,
                DEFAULT_SERVICES_CONTEXT);
    }

    public String getServicesMapping() {
        return propertiesManager.getAttribute(SERVICES_MAPPING,
                DEFAULT_SERVICES_MAPPING);
    }

    /**
     * Currently support only http protocol
     * 
     * @return
     */
    public String getProtocol() {
        return DEFAULT_PROTOCOL;
    }

    /**
     * Get the default component properties
     * 
     * @return
     */
    protected static Map<String, String> getDefaultProperties() {
        Map<String, String> result = new HashMap<String, String>(2);
        result.put(HTTP_PORT, Integer.toString(DEFAULT_HTTP_PORT));
        result.put(ENABLE_SERVICES_LIST, Boolean
                .toString(DEFAULT_ENABLE_SERVICES_LIST));
        result.put(SERVICES_CONTEXT, DEFAULT_SERVICES_CONTEXT);
        result.put(SERVICES_MAPPING, DEFAULT_SERVICES_MAPPING);

        return result;
    }

}
