/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.binding.soap.listener.incoming;

/**
 * This class is used to store only the SOAP server related configuration
 * values.
 *
 * @author Christophe HAMERLING - eBMWebSourcing
 *
 */
public class SoapServerConfig {

    /**
     * The port used for incoming SOAP requests
     */
    private int port;

    /**
     * The current host
     */
    private String host;

    /**
     * The servlet mappping : axis2/<b>services</b>
     */
    private String servicesMapping;

    /**
     * The servlet context : <b>axis2</b>/services
     */
    private String servicesContext;

    /**
     * The protocol used for this server (http / https ...)
     */
    private String protocol;

    /**
     * The server provides/!provides the services list
     */
    private boolean providesList;

    /**
     * Creates a new instance of {@link SoapServerConfig}
     *
     */
    public SoapServerConfig() {
    }

    /**
     * @return the port
     */
    public int getPort() {
        return port;
    }

    /**
     * @param port
     *            the port to set
     */
    public void setPort(int port) {
        this.port = port;
    }

    /**
     * @return the providesList
     */
    public boolean isProvidesList() {
        return providesList;
    }

    /**
     * @param providesList
     *            the providesList to set
     */
    public void setProvidesList(boolean providesList) {
        this.providesList = providesList;
    }

    /**
     * @return the host
     */
    public String getHost() {
        return host;
    }

    /**
     * @param host
     *            the host to set
     */
    public void setHost(String host) {
        this.host = host;
    }

    /**
     * @return the protocol
     */
    public String getProtocol() {
        return protocol;
    }

    /**
     * @param protocol
     *            the protocol to set
     */
    public void setProtocol(String protocol) {
        this.protocol = protocol;
    }

    /**
     * @return the servicesContext
     */
    public String getServicesContext() {
        return servicesContext;
    }

    /**
     * @param servicesContext
     *            the servicesContext to set
     */
    public void setServicesContext(String servicesContext) {
        this.servicesContext = servicesContext;
    }

    /**
     * @return the servicesMapping
     */
    public String getServicesMapping() {
        return servicesMapping;
    }

    /**
     * @param servicesMapping
     *            the servicesMapping to set
     */
    public void setServicesMapping(String servicesMapping) {
        this.servicesMapping = servicesMapping;
    }

    /**
     * Build the services URL from the current configuration properties
     *
     * @return
     */
    public String buildServicesURL() {
        StringBuffer sb = new StringBuffer(getProtocol());
        sb.append("://");
        sb.append(getHost());
        if (getPort() > 0) {
            sb.append(':');
            sb.append(getPort());
        }
        sb.append('/');
        sb.append(getServicesContext());
        sb.append('/');
        sb.append(getServicesMapping());
        return sb.toString();
    }
}
